@@ -10,7 +10,6 @@ try:
 except ImportError:  # pragma: nocover
     LIBMAGIC_AVAILABLE = False  # pragma: nocover
 
-
 from unstructured.logger import logger
 from unstructured.nlp.patterns import EMAIL_HEAD_RE
 
@@ -38,11 +37,21 @@ PPT_MIME_TYPES = [
     "application/vnd.ms-powerpoint",
 ]
 
+TXT_MIME_TYPES = [
+    "text/plain",
+    "message/rfc822",  # ref: https://www.rfc-editor.org/rfc/rfc822
+]
+
 MD_MIME_TYPES = [
     "text/markdown",
     "text/x-markdown",
 ]
 
+EPUB_MIME_TYPES = [
+    "application/epub",
+    "application/epub+zip",
+]
+
 # NOTE(robinson) - .docx.xlsx files are actually zip file with a .docx/.xslx extension.
 # If the MIME type is application/octet-stream, we check if it's a .docx/.xlsx file by
 # looking for expected filenames within the zip file.
@@ -84,11 +93,13 @@ class FileType(Enum):
     EML = 40
     RTF = 41
     TXT = 42
+    JSON = 43
 
     # Markup Types
     HTML = 50
     XML = 51
     MD = 52
+    EPUB = 53
 
     # Compressed Types
     ZIP = 60
@@ -117,6 +128,8 @@ EXT_TO_FILETYPE = {
     ".xls": FileType.XLS,
     ".ppt": FileType.PPT,
     ".rtf": FileType.RTF,
+    ".json": FileType.JSON,
+    ".epub": FileType.EPUB,
 }
 
 
@@ -155,6 +168,9 @@ def detect_filetype(
     if mime_type == "application/pdf":
         return FileType.PDF
 
+    elif mime_type == "application/json":
+        return FileType.JSON
+
     elif mime_type in DOCX_MIME_TYPES:
         return FileType.DOCX
 
@@ -171,7 +187,10 @@ def detect_filetype(
         # NOTE - I am not sure whether libmagic ever returns these mimetypes.
         return FileType.MD
 
-    elif mime_type == "text/plain":
+    elif mime_type in EPUB_MIME_TYPES:
+        return FileType.EPUB
+
+    elif mime_type in TXT_MIME_TYPES:
         if extension and extension == ".eml":
             return FileType.EML
         if extension and extension == ".md":
@@ -218,13 +237,15 @@ def detect_filetype(
             with open(filename, "rb") as f:
                 filetype = _detect_filetype_from_octet_stream(file=f)
 
+        extension = extension if extension else ""
         if filetype == FileType.UNK:
-            return FileType.ZIP
+            return EXT_TO_FILETYPE.get(extension.lower(), FileType.ZIP)
         else:
-            return filetype
+            return EXT_TO_FILETYPE.get(extension.lower(), filetype)
 
-    logger.warn(
-        f"MIME type was {mime_type}. This file type is not currently supported in unstructured.",
+    logger.warning(
+        f"The MIME type{f' of {filename!r}' if filename else ''} is {mime_type!r}. "
+        "This file type is not currently supported in unstructured.",
     )
     return FileType.UNK
 
