@@ -5,6 +5,7 @@ import requests
 
 from unstructured.documents.elements import Element
 from unstructured.documents.xml import VALID_PARSERS
+from unstructured.partition.common import exactly_one
 from unstructured.partition.html import partition_html
 
 
@@ -23,20 +24,17 @@ def partition_md(
     include_metadata: bool = True,
     parser: VALID_PARSERS = None,
 ) -> List[Element]:
-    if not any([filename, file, text, url]):
-        raise ValueError("One of filename, file, or text must be specified.")
+    # Verify that only one of the arguments was provided
+    exactly_one(filename=filename, file=file, text=text, url=url)
 
-    if filename is not None and not file and not text and not url:
+    if filename is not None:
         with open(filename, encoding="utf8") as f:
             text = optional_decode(f.read())
 
-    elif file is not None and not filename and not text and not url:
+    elif file is not None:
         text = optional_decode(file.read())
 
-    elif text is not None and not filename and not file and not url:
-        pass
-
-    elif url is not None and not filename and not file and not text:
+    elif url is not None:
         response = requests.get(url)
         if not response.ok:
             raise ValueError(f"URL return an error: {response.status_code}")
@@ -47,8 +45,8 @@ def partition_md(
 
         text = response.text
 
-    else:
-        raise ValueError("Only one of filename, file, or text can be specified.")
+    elif text is None:
+        raise ValueError("Exactly one of filename, file, url or text must be specified.")
 
     html = markdown.markdown(text)
 
